@@ -1,4 +1,4 @@
-class Decorator(object):
+class Decorum(object):
     """
     A decorator class that tries to unify writing decorators
     for use with and without arguments.
@@ -27,8 +27,12 @@ class Decorator(object):
         else:
             wrapped = self.wraps(f)
             if self.keep_attrs:
-                wrapped.__doc__ = f.__doc__
-                wrapped.__name__ = f.__name__
+                for attr in ('__doc__', '__name__'):
+                    try:
+                        setattr(wrapped, attr, getattr(f, attr))
+                    except AttributeError:
+                        print 'oops'
+                        pass
             return wrapped
 
     def wraps(self, f):
@@ -38,3 +42,9 @@ class Decorator(object):
     def init(self, *args, **kwargs):
         """Passed any possible arguments to decorator"""
         pass
+
+
+def decorator(cls):
+    class decorated(cls, Decorum):
+        pass
+    return decorated
